summary refs log tree commit diff
path: root/benchtests/bench-util.c
diff options
context:
space:
mode:
Diffstat (limited to 'benchtests/bench-util.c')
-rw-r--r--benchtests/bench-util.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/benchtests/bench-util.c b/benchtests/bench-util.c
index d684b78054..4996f8c4ac 100644
--- a/benchtests/bench-util.c
+++ b/benchtests/bench-util.c
@@ -22,12 +22,12 @@ static volatile unsigned int dontoptimize = 0;
 void
 bench_start (void)
 {
   /* This loop should cause CPU to switch to maximal freqency.
      This makes subsequent measurement more accurate.  We need a side effect
      to prevent the loop being deleted by compiler.
      This should be enough to cause CPU to speed up and it is simpler than
      running loop for constant time.  This is used when user does not have root
-     access to set a constant freqency.  */
+     access to set a constant frequency.  */
 
   for (int k = 0; k < START_ITER; k++)
     dontoptimize += 23 * dontoptimize + 2;
@@ -22,12 +22,12 @@ static volatile unsigned int dontoptimize = 0;
 bench_start (void)
 {
-  /* This loop should cause CPU to switch to maximal freqency.
+  /* This loop should cause CPU to switch to maximal frequency.
      This makes subsequent measurement more accurate.  We need a side effect
      to prevent the loop being deleted by compiler.